@@ -2,5 +2,5 @@ use nxui::window::demowindow::DemoWindow;
 
 fn main() {
     let win = DemoWindow::new();
-    nxui::nxui::run_app(Box::new(win));
+    nxui::nxui::create_new_app(Box::new(win));
 }
