@@ -21,7 +21,7 @@ impl Application for DemoWindow {
     }
 
     fn attributes(&self) -> WindowAttributes {
-        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
+        WindowAttributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100,false)
     }
 
     fn startup(&self,storage: Storage) {
