@@ -5,7 +5,7 @@ use crate::io::storage::Storage;
 pub mod demowindow;
 
 #[cfg(windows)]
-#[derive(Debug,Copy,Clone)]
+#[derive(Clone)]
 pub struct Frame {
     /// Window body
     handle: windows_sys::Win32::Foundation::HWND
@@ -86,19 +86,21 @@ pub struct WindowAttributes {
     pub width: i32,
     pub height: i32,
     pub x: i32,
-    pub y: i32
+    pub y: i32,
+    pub is_childwindow: bool
 }
 
 #[cfg(windows)]
 impl WindowAttributes {
-    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32,is_childwindow: bool) -> Self {
         Self {
             style,
             title,
             width,
             height,
             x,
-            y
+            y,
+            is_childwindow
         }
     }
 }
@@ -149,6 +151,7 @@ pub trait Application {
     fn startup(&self,storage: Storage) {
 
     }
+
     /// Writing UI processes and events
     fn ui(&self,frame: Frame);
     /// Processing at application termination (optional)
@@ -156,10 +159,8 @@ pub trait Application {
     }
 }
 
-
-
 #[cfg(unix)]
-#[derive(Debug,Copy,Clone)]
+#[derive(Clone)]
 pub struct Frame {
     /// Window body
     handle: gtk::Window
@@ -206,7 +207,8 @@ impl Frame {
 
     /// Returns the window handle.
     pub fn get_window(&self) -> gtk::Window {
-        self.handle
+        use std::borrow::Borrow;
+        self.handle.borrow().clone()
     }
 
     /// Set window position
@@ -232,19 +234,51 @@ pub struct WindowAttributes {
     pub width: i32,
     pub height: i32,
     pub x: i32,
-    pub y: i32
+    pub y: i32,
+    pub is_childwindow: bool
 }
 
 #[cfg(unix)]
 impl WindowAttributes {
-    pub fn new(style: gtk::WindowType,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: gtk::WindowType,title: String,width: i32,height: i32,x: i32,y: i32,is_childwindow: bool) -> Self {
         Self {
             style,
             title,
             width,
             height,
             x,
-            y
+            y,
+            is_childwindow
+        }
+    }
+}
+
+#[cfg(unix)]
+#[cfg(feature="nxui-awc")]
+pub struct AdvancedOptions {
+    advanced_style: gtk::gdk::WindowTypeHint
+}
+
+#[cfg(unix)]
+#[cfg(feature="nxui-awc")]
+impl AdvancedOptions {
+    pub fn new(advanced_style: gtk::gdk::WindowTypeHint) -> Self {
+        Self {
+            advanced_style
+        }
+    }
+
+    pub fn get_style(&self) -> gtk::gdk::WindowTypeHint {
+        self.advanced_style
+    }
+}
+
+#[cfg(unix)]
+#[cfg(feature="nxui-awc")]
+impl Default for AdvancedOptions {
+    fn default() -> Self {
+        Self {
+            advanced_style: gtk::gdk::WindowTypeHint::Normal
         }
     }
 }
@@ -255,6 +289,12 @@ pub trait Application {
     fn app_name(&self) -> String;
     /// Returns WindowAttributes.
     fn attributes(&self) -> WindowAttributes;
+
+    #[cfg(feature="nxui-awc")]
+    fn advanced_options(&self) -> AdvancedOptions {
+        AdvancedOptions::default()
+    }
+
     /// Processing at application startup (optional)
     fn startup(&self,storage: Storage) {
 
